@@ -14,6 +14,7 @@
 #define ITEM_MAXSIZE    100
 
 Position DockItem::DockPosition = Position::Top;
+int DockItem::DockSize = 40;
 DisplayMode DockItem::DockDisplayMode = DisplayMode::Efficient;
 QPointer<DockPopupWindow> DockItem::PopupWindow(nullptr);
 
@@ -29,7 +30,7 @@ DockItem::DockItem(QWidget *parent)
     if (PopupWindow.isNull()) {
         DockPopupWindow *arrowRectangle = new DockPopupWindow(nullptr);
         arrowRectangle->setShadowBlurRadius(20);
-        arrowRectangle->setRadius(18);
+        arrowRectangle->setRadius(6);
         arrowRectangle->setShadowYOffset(2);
         arrowRectangle->setShadowXOffset(0);
         arrowRectangle->setArrowWidth(18);
@@ -77,6 +78,11 @@ void DockItem::setDockPosition(const Position side)
     DockPosition = side;
 }
 
+void DockItem::setDockSize(const int size)
+{
+    DockSize = size;
+}
+
 void DockItem::setDockDisplayMode(const DisplayMode mode)
 {
     DockDisplayMode = mode;
@@ -264,13 +270,9 @@ void DockItem::showHoverTips()
     showPopupWindow(content);
 }
 
-void DockItem::showPopupWindow(QWidget *const content, const bool model)
+void DockItem::showPopupWindow(QWidget *const content, const bool model, const int radius)
 {
-    if(itemType() == App){
-        PopupWindow->setRadius(18);
-    }else {
-        PopupWindow->setRadius(6);
-    }
+    PopupWindow->setRadius(radius);
 
     m_popupShown = true;
     m_lastPopupWidget = content;
