@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2018 ~ 2020 Deepin Technology Co., Ltd.
- *
- * Author:     fanpengcheng <fanpengcheng_cm@deepin.com>
- *
- * Maintainer: fanpengcheng <fanpengcheng_cm@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #ifndef MULTISCREENWORKER_H
 #define MULTISCREENWORKER_H
@@ -35,7 +18,6 @@
 #include <QFlag>
 #include <QDebug>
 
-#define WINDOWMARGIN ((m_displayMode == Dock::Efficient) ? 0 : 10)
 #define ANIMATIONTIME 300
 #define FREE_POINT(p) if (p) {\
         delete p;\
