@@ -13,8 +13,12 @@ DesktopWidget::DesktopWidget(QWidget *parent)
     : QWidget (parent)
     , m_isHover(false)
     , m_needRecoveryWin(false)
+    ,m_timer(new QTimer(this))
 {
     setMouseTracking(true);
+    m_timer->setInterval(0);
+    m_timer->setSingleShot(true);
+    connect(m_timer, &QTimer::timeout, this, &DesktopWidget::toggleDesktop);
 }
 
 void DesktopWidget::paintEvent(QPaintEvent *event)
@@ -41,7 +45,9 @@ void DesktopWidget::enterEvent(QEvent *event)
 {
     if (checkNeedShowDesktop()) {
         m_needRecoveryWin = true;
-        QProcess::startDetached("/usr/lib/deepin-daemon/desktop-toggle");
+//        QProcess::startDetached("/usr/lib/deepin-daemon/desktop-toggle");
+        if (m_timer)
+            m_timer->start();
     }
 
     m_isHover = true;
@@ -54,7 +60,10 @@ void DesktopWidget::leaveEvent(QEvent *event)
 {
     // 鼠标移入时隐藏了窗口，移出时恢复
     if (m_needRecoveryWin) {
-        QProcess::startDetached("/usr/lib/deepin-daemon/desktop-toggle");
+        if (m_timer->isActive())
+            m_timer->stop();
+        else
+            toggleDesktop();
     }
 
     m_isHover = false;
@@ -71,13 +80,25 @@ void DesktopWidget::mousePressEvent(QMouseEvent *event)
             m_needRecoveryWin = false;
         } else {
             // 需求调整，鼠标移入，预览桌面时再点击显示桌面保持显示桌面状态，再点击才切换桌面显、隐状态
-            QProcess::startDetached("/usr/lib/deepin-daemon/desktop-toggle");
+            toggleDesktop();
         }
     }
 
     QWidget::mousePressEvent(event);
 }
 
+void DesktopWidget::toggleDesktop()
+{
+    QProcess::startDetached("/usr/lib/deepin-daemon/desktop-toggle");
+}
+
+void DesktopWidget::setToggleDesktopInterval(int ms)
+{
+    if (m_timer) {
+        m_timer->setInterval(ms);
+    }
+}
+
 /**
  * @brief ShowDesktopWidget::checkNeedShowDesktop 根据窗管提供接口（当前是否显示的桌面），提供鼠标
  * 移入 显示桌面窗口 区域时，是否需要显示桌面判断依据
